@@ -1781,7 +1781,7 @@ function osa_pressOnAnalytique() {
 			else if (numCompte=="*") {
 				osa_popupVentilation();
 			}
-			else {			
+			else {
 				var qSearch = new QueryHttp("Compta/Analytique/Comptes/searchNumCompte.tmpl");
 				qSearch.setParam("Num_Compte", numCompte);
 				qSearch.setParam("Search_Like", true);
@@ -2198,7 +2198,13 @@ function osa_loadModeleByRaccourci(raccourci) {
 		qLoad.setParam("Raccourci", raccourci);
 		var result = qLoad.execute();
 
-		osa_loadLignes(result.responseXML.documentElement.getElementsByTagName("ligneModele"));
+		var errors = new Errors(result);
+		if (errors.hasNext()) {
+			errors.show();
+		}
+		else {
+			osa_loadLignes(result.responseXML.documentElement.getElementsByTagName("ligneModele"));
+		}
 
 	} catch (e) {
 		recup_erreur(e);
