@@ -26,6 +26,8 @@ function opvt_init() {
 		document.getElementById("opvt-GAC_Drop_Possible_Auto").collapsed = !adminMode;
 		document.getElementById("opvt-GAC_Creneau_Livraison").collapsed = !adminMode;
 		document.getElementById("opvt-Restocking_Prio_Recep").collapsed = !adminMode;
+		document.getElementById("opvt-GDV_Prime_CEE").collapsed = !adminMode;
+		document.getElementById("opvt-GDV_Situation").collapsed = !adminMode;
 
 	} catch (e) {
     recup_erreur(e);
@@ -375,6 +377,7 @@ function opvt_loadPreferences() {
 		document.getElementById("opvt-Show_Intitule_Cde_CC").checked = contenu.getAttribute("Show_Intitule_Cde_CC")=="true";
 		document.getElementById("opvt-Imp_RIB_CC").value = contenu.getAttribute("Imp_RIB_CC");
 		document.getElementById("opvt-Imp_RIB_DC").value = contenu.getAttribute("Imp_RIB_DC");
+		document.getElementById("opvt-Imp_RIB_PF").value = contenu.getAttribute("Imp_RIB_PF");
 		document.getElementById("opvt-Email_VCC").value = contenu.getAttribute("Email_VCC");
 		document.getElementById("opvt-Email_ACC").value = contenu.getAttribute("Email_ACC");
 		document.getElementById("opvt-Email_ECC").value = contenu.getAttribute("Email_ECC");
@@ -469,6 +472,9 @@ function opvt_loadPreferences() {
 		document.getElementById("opvt-Message_SMS_RCC").value = contenu.getAttribute("Message_SMS_RCC");
 		document.getElementById("opvt-Config_SMS_RCC").value = contenu.getAttribute("Config_SMS_RCC");
 		document.getElementById("opvt-Ret_Comp_SMS_RCC").checked = contenu.getAttribute("Ret_Comp_SMS_RCC")=="true";
+		document.getElementById("opvt-GAC_Alerte_MR_FC").checked = contenu.getAttribute("GAC_Alerte_MR_FC")=="true";
+		document.getElementById("opvt-GDV_Prime_CEE").checked = contenu.getAttribute("GDV_Prime_CEE")=="true";
+		document.getElementById("opvt-GDV_Situation").checked = contenu.getAttribute("GDV_Situation")=="true";
 
 		opvt_chargerDepots(contenu.getAttribute("GAC_Def_Filtre_Depot"));
 
@@ -523,6 +529,7 @@ function opvt_updatePreferences() {
 		var showIntituleCdeCC = document.getElementById("opvt-Show_Intitule_Cde_CC").checked;
 		var impRIBCC = document.getElementById("opvt-Imp_RIB_CC").value;
 		var impRIBDC = document.getElementById("opvt-Imp_RIB_DC").value;
+		var impRIBPF = document.getElementById("opvt-Imp_RIB_PF").value;
 		var emailVCC = document.getElementById("opvt-Email_VCC").value;
 		var emailACC = document.getElementById("opvt-Email_ACC").value;
 		var emailECC = document.getElementById("opvt-Email_ECC").value;
@@ -617,6 +624,9 @@ function opvt_updatePreferences() {
 		var configSMSRCC = document.getElementById("opvt-Config_SMS_RCC").value;
 		var retCompSMSRCC = document.getElementById("opvt-Ret_Comp_SMS_RCC").checked;
 		var gacDefFiltreDepot = document.getElementById("opvt-GAC_Def_Filtre_Depot").value;
+		var gacAlerteMRFC = document.getElementById("opvt-GAC_Alerte_MR_FC").checked;
+		var gdvPrimeCEE = document.getElementById("opvt-GDV_Prime_CEE").checked;
+		var gdvSituation = document.getElementById("opvt-GDV_Situation").checked;
 
 		if (defModeFacturation=="B" && defFactAvantLiv) {
 			showWarning("Le mode de facturation par bon de livraison et l'option facturable avant livraison sont incompatibles");
@@ -690,6 +700,7 @@ function opvt_updatePreferences() {
 			qUpdate.setParam("Show_Intitule_Cde_CC", showIntituleCdeCC);
 			qUpdate.setParam("Imp_RIB_CC", impRIBCC);
 			qUpdate.setParam("Imp_RIB_DC", impRIBDC);
+			qUpdate.setParam("Imp_RIB_PF", impRIBPF);
 			qUpdate.setParam("Email_VCC", emailVCC);
 			qUpdate.setParam("Email_ACC", emailACC);
 			qUpdate.setParam("Email_ECC", emailECC);
@@ -784,6 +795,9 @@ function opvt_updatePreferences() {
 			qUpdate.setParam("Config_SMS_RCC", configSMSRCC);
 			qUpdate.setParam("Ret_Comp_SMS_RCC", retCompSMSRCC);
 			qUpdate.setParam("GAC_Def_Filtre_Depot", gacDefFiltreDepot);
+			qUpdate.setParam("GAC_Alerte_MR_FC", gacAlerteMRFC);
+			qUpdate.setParam("GDV_Prime_CEE", gdvPrimeCEE);
+			qUpdate.setParam("GDV_Situation", gdvSituation);
 
 			var result = qUpdate.execute();
 
