@@ -17,6 +17,7 @@ var ofa_defPeriodeFacturation;
 var ofa_defModeEnvoiFacture;
 var ofa_listCommandeAFacturer;
 var ofa_listBonLivraisonAFacturer;
+var ofa_pourcentageFS;
 var ofa_etatAffaire;
 var ofa_numAffaire = "";
 var ofa_modified;
@@ -24,6 +25,7 @@ var ofa_chargerResponsable;
 var ofa_chargement;
 var ofa_clientId = "";
 var ofa_gestionResp;
+var ofa_hasPrimeCEE;
 
 
 
@@ -52,6 +54,14 @@ function ofa_init() {
 		ofa_defModeEnvoiFacture = gConfig.getDefModeEnvoiFacture();
 		document.getElementById('ofa-chkSansLivraison').collapsed = !gConfig.isSpecSL();
 
+		if (gConfig.isGDVSituation()) {
+			document.getElementById('ofa-modeFactFS').setAttribute("hidden", false);
+		}
+
+		if (gConfig.isGDVPrimeCEE()) {
+			document.getElementById('ofa-modeFactPE').setAttribute("hidden", false);
+		}
+
 		ofa_chargerResponsables(gProfil.getLoggedUser());
 		ofa_gestionResp = gProfil.isGestionRespVente();
 
@@ -112,9 +122,10 @@ function ofa_reinitialiser() {
 		ofa_setModified(false);
 		ofa_chargerResponsable = "";
 		ofa_clientId = "";
+		ofa_hasPrimeCEE = false;
 
 		document.getElementById('ofa-modeFacturation').value = ofa_defModeFacturation;
-		document.getElementById('ofa-factAvantLiv').checked = ofa_defFactAvantLiv;
+		document.getElementById('ofa-factAvantLiv').checked = ofa_defFactAvantLiv || ofa_defModeFacturation=="S" || ofa_defModeFacturation=="P";
 		document.getElementById('ofa-chkSansLivraison').checked = false;
 		document.getElementById('ofa-periodeFacturation').value = ofa_defPeriodeFacturation;
 		document.getElementById('ofa-dateDebutPeriode').value = "";
@@ -190,6 +201,7 @@ function ofa_reinitialiser() {
 		ofa_aListeCommandes.deleteTree();
 		ofa_aListeBL.deleteTree();
 		ofa_aListeFacturesAvoirs.deleteTree();
+
 	} catch (e) {
 		recup_erreur(e);
 	}
@@ -209,7 +221,8 @@ function ofa_nouvelleAffaire() {
 		document.getElementById('ofa-intitule').disabled = false;
 		document.getElementById('ofa-responsable').disabled = !ofa_gestionResp;
 		document.getElementById('ofa-modeFacturation').disabled = false;
-		document.getElementById('ofa-factAvantLiv').disabled = (modeFacturation=="B");
+		document.getElementById('ofa-factAvantLiv').disabled = (modeFacturation=="B" || modeFacturation=="S" || modeFacturation=="P");
+		document.getElementById('ofa-rowFactAvantLiv').collapsed = modeFacturation=="S" || modeFacturation=="P";
 		document.getElementById('ofa-chkSansLivraison').disabled = false;
 		document.getElementById('ofa-periodeFacturation').disabled = false;
 		document.getElementById('ofa-dateDebutPeriode').disabled = false;
@@ -274,6 +287,7 @@ function ofa_chargerAffaire() {
 		document.getElementById('ofa-creation').setAttribute("label","Affaire cr\u00E9\u00E9e le "+ contenu.getAttribute('Date_Creation') +" par "+ contenu.getAttribute('Login_Createur'));
 		document.getElementById('ofa-modification').setAttribute("label","Derni\u00E8re modification le "+ contenu.getAttribute('Date_Maj') +" par "+ contenu.getAttribute('Login_Maj'));
 		document.getElementById('ofa-fiche').setAttribute("label","Affaire N\u00B0"+ ofa_numAffaire);
+		ofa_hasPrimeCEE = contenu.getAttribute("Has_Prime_CEE")=="true";
 
 		document.getElementById('ofa-nbCommandesEnCours').value = contenu.getAttribute("Nb_Commandes_En_Cours");
 		document.getElementById('ofa-caHTCommandesEnCours').value = contenu.getAttribute("CAHT_Commandes_En_Cours") +" \u20AC";
@@ -378,10 +392,11 @@ function ofa_activerModeFacturation() {
 		var modeFacturation = document.getElementById('ofa-modeFacturation').value;
 		var sansLivraison = document.getElementById('ofa-chkSansLivraison').checked;
 		var periodeFact = document.getElementById('ofa-periodeFacturation').value;
-		document.getElementById('ofa-modeFacturation').disabled = desactiver;
+		document.getElementById('ofa-modeFacturation').disabled = desactiver || ofa_hasPrimeCEE;
 		document.getElementById('ofa-periodeFacturation').disabled = desactiver;
 		document.getElementById('ofa-dateDebutPeriode').disabled = (desactiver || periodeFact!="D");
-		document.getElementById('ofa-factAvantLiv').disabled = (desactiver || sansLivraison || modeFacturation=="B");
+		document.getElementById('ofa-factAvantLiv').disabled = (desactiver || sansLivraison || modeFacturation=="B" || modeFacturation=="S" || modeFacturation=="P");
+		document.getElementById('ofa-rowFactAvantLiv').collapsed = modeFacturation=="S" || modeFacturation=="P";
 		document.getElementById('ofa-chkSansLivraison').disabled = (desactiver || ofa_aListeBL.nbLignes()>0 || modeFacturation=="B");
 
 		ofa_activerBoutons();
@@ -525,7 +540,7 @@ function ofa_chargerCoord() {
 		var factAvantLiv = contenu.getAttribute('Fact_Avant_Liv')=="true";
 
 		document.getElementById('ofa-modeFacturation').value = modeFacturation;
-		document.getElementById('ofa-factAvantLiv').checked = factAvantLiv;
+		document.getElementById('ofa-factAvantLiv').checked = factAvantLiv || modeFacturation=="S" || modeFacturation=="P";
 		document.getElementById('ofa-chkSansLivraison').checked = false;
 		document.getElementById('ofa-periodeFacturation').value = contenu.getAttribute('Periode_Facturation');
 		document.getElementById('ofa-dateDebutPeriode').value = "";
@@ -533,7 +548,8 @@ function ofa_chargerCoord() {
 		document.getElementById('ofa-modeEnvoiFacture').value = contenu.getAttribute('Mode_Envoi_Facture');
 
 		document.getElementById('ofa-chkSansLivraison').disabled = (modeFacturation=="B");
-		document.getElementById('ofa-factAvantLiv').disabled = (modeFacturation=="B");
+		document.getElementById('ofa-factAvantLiv').disabled = (modeFacturation=="B" || modeFacturation=="S" || modeFacturation=="P");
+		document.getElementById('ofa-rowFactAvantLiv').collapsed = modeFacturation=="S" || modeFacturation=="P";
 
 		ofa_setModified(true);
 
@@ -612,14 +628,16 @@ function ofa_enregistrerAffaire() {
 		var periodeFacturation = document.getElementById('ofa-periodeFacturation').value;
 		var dateDebutPeriode = document.getElementById('ofa-dateDebutPeriode').value;
 
-		if (isEmpty(denomination)) { showWarning("Veuillez saisir la d\u00E9nomination du client !"); }
+		if (isEmpty(denomination)) { showWarning("Veuillez saisir la d\u00E9nomination du client"); }
 		else if (!isEmpty(tel1) && !isPhone(tel1) && !document.getElementById('ofa-tel1').disabled) { showWarning("T\u00E9l\u00E9phone 1 incorrect"); }
 		else if (!isEmpty(tel2) && !isPhone(tel2) && !document.getElementById('ofa-tel2').disabled) { showWarning("T\u00E9l\u00E9phone 2 incorrect"); }
 		else if (gShowFax && !isEmpty(fax) && !isPhone(fax) && !document.getElementById('ofa-fax').disabled) { showWarning("Fax incorrect"); }
-		else if (!isEmpty(email) && !isEmail(email) && document.getElementById('ofa-email').getAttribute("readonly")!="true") { showWarning("L'adresse e-mail du client est incorrecte !"); }
-		else if (modeFacturation=="B" && factAvantLiv) { showWarning("Le type de facturation par BL et le mode de facturation par commande sont incompatibles !"); }
-		else if (sansLivraison && !factAvantLiv) { showWarning("Le mode de facturation ne peut \u00EAtre que par commande !"); }
-		else if (periodeFacturation=="D" && !isDate(dateDebutPeriode)) { showWarning("La date de d\u00E9but de p\u00E9riode est incorrecte !"); }
+		else if (!isEmpty(email) && !isEmail(email) && document.getElementById('ofa-email').getAttribute("readonly")!="true") { showWarning("L'adresse e-mail du client est incorrecte"); }
+		else if (modeFacturation=="B" && factAvantLiv) { showWarning("Le mode de facturation par BL et la facturation avant livraison sont incompatibles"); }
+		else if (modeFacturation=="S" && !factAvantLiv) { showWarning("L'option de facturation avant livraison doit \u00EAtre coch\u00E9e avec le mode de facturation de situation"); }
+		else if (modeFacturation=="P" && !factAvantLiv) { showWarning("L'option de facturation avant livraison doit \u00EAtre coch\u00E9e avec le mode de facturation prime CEE"); }
+		else if (sansLivraison && !factAvantLiv) { showWarning("L'option de facturation avant livraison doit \u00EAtre coch\u00E9e avec l'option sans livraison"); }
+		else if (periodeFacturation=="D" && !isDate(dateDebutPeriode)) { showWarning("La date de d\u00E9but de p\u00E9riode est incorrecte"); }
 		else {
 
 			var qSave;
@@ -786,7 +804,7 @@ function ofa_pressOnNouvelleExpedition(typeExpedition) {
 			var listCommandeExpediable = contenu.getAttribute('List_Commande_Id');
 			var conflit = contenu.getAttribute('Conflit')=="true";
 
-			if (conflit) {				
+			if (conflit) {
 				var url = "chrome://opensi/content/facturation/user/affaires/popup-choixCommandeAExpedier.xul";
   			window.openDialog(url,'','chrome,modal,centerscreen', ofa_retourChoixCommandeAExpedier, listCommandeExpediable);
   		}
@@ -882,7 +900,7 @@ function ofa_selectOnListeFacturesAvoirs() {
 function ofa_pressOnNouvelleFacture() {
 	try {
 
-		document.activeElement.blur(); // ncessaire sinon cration possible de pleins de factures par la touche entre
+		document.activeElement.blur(); // ncessaire sinon cration possible de plein de factures par la touche entre
 
 		var modeFacturation = document.getElementById('ofa-modeFacturation').value;
 		var factAvantLiv = document.getElementById('ofa-factAvantLiv').checked;
@@ -914,7 +932,7 @@ function ofa_pressOnNouvelleFacture() {
 				}
 				else {
 					if (factAvantLiv) {
-						if (modeFacturation=="C") {
+						if (modeFacturation=="C" || modeFacturation=="S" || modeFacturation=="P") {
 							var url = "chrome://opensi/content/facturation/user/affaires/popup-choixCommandeAFacturer.xul";
 	  					window.openDialog(url,'','chrome,modal,centerscreen', ofa_retourChoixCommandeAFacturer, listCommandeFacturable);
 						}
@@ -941,11 +959,21 @@ function ofa_pressOnNouvelleFacture() {
 			}
 		}
 
-		if (!isEmpty(ofa_listCommandeAFacturer) || !isEmpty(ofa_listBonLivraisonAFacturer)) {
+		if (modeFacturation=="S" && !isEmpty(ofa_listCommandeAFacturer)) {
+			ofa_pourcentageFS = 0;
+			var url = "chrome://opensi/content/facturation/user/affaires/popup-facturationSituation.xul";
+ 			window.openDialog(url,'','chrome,modal,centerscreen', ofa_retourFacturationSituation, ofa_listCommandeAFacturer);
+		}
+
+		if ((!isEmpty(ofa_listCommandeAFacturer) || !isEmpty(ofa_listBonLivraisonAFacturer)) && (modeFacturation!="S" || parseFloat(ofa_pourcentageFS)>0)) {
+
 			var qCreate = new QueryHttp("Facturation/Affaires/createFactureClient.tmpl");
 			qCreate.setParam("Affaire_Id", ofa_affaireId);
 			qCreate.setParam("List_Commande_Id", ofa_listCommandeAFacturer);
 			qCreate.setParam("List_Bon_Liv_Id", ofa_listBonLivraisonAFacturer);
+			if (modeFacturation=="S") {
+				qCreate.setParam("Pourcentage_FS", ofa_pourcentageFS);
+			}
 
 		  var result = qCreate.execute();
 
@@ -1026,6 +1054,17 @@ function ofa_retourChoixGroupeCommandePaysAFacturer(listCommandeId, listBonLivId
 }
 
 
+function ofa_retourFacturationSituation(pourcentageFS) {
+	try {
+
+		ofa_pourcentageFS = pourcentageFS;
+
+	} catch (e) {
+		recup_erreur(e);
+	}
+}
+
+
 function ofa_pressOnNouvelAvoir() {
 	try {
 
@@ -1104,7 +1143,11 @@ function ofa_pressOnModeFacturation() {
 			document.getElementById('ofa-factAvantLiv').checked = false;
 			document.getElementById('ofa-chkSansLivraison').checked = false;
 		}
-		document.getElementById('ofa-factAvantLiv').disabled = (modeFacturation=="B");
+		if (modeFacturation=="S" || modeFacturation=="P") {
+			document.getElementById('ofa-factAvantLiv').checked = true;
+		}
+		document.getElementById('ofa-factAvantLiv').disabled = (modeFacturation=="B" || modeFacturation=="S" || modeFacturation=="P");
+		document.getElementById('ofa-rowFactAvantLiv').collapsed = (modeFacturation=="S" || modeFacturation=="P");
 		document.getElementById('ofa-chkSansLivraison').disabled = (modeFacturation=="B");
 
 	} catch (e) {
