@@ -326,6 +326,7 @@ function oma_initCriteres() {
 		document.getElementById('oma-etatCommande').value = oma_defautEtatCommande;
 		document.getElementById('oma-etatLogistique').value = oma_defautEtatLogistique;
 		document.getElementById('oma-bloque').selectedIndex = 0;
+		document.getElementById('oma-facturable').checked = false;
 		document.getElementById('oma-dateCommandeDebut').value = "";
 		document.getElementById('oma-dateCommandeFin').value = "";
 		document.getElementById('oma-dateExpeditionDebut').value = "";
@@ -392,6 +393,7 @@ function oma_listerCommandes() {
 		var etatCommande = document.getElementById('oma-etatCommande').value;
 		var etatLogistique = document.getElementById('oma-etatLogistique').value;
 		var commandeBloquee = document.getElementById('oma-bloque').value;
+		var facturable = document.getElementById('oma-facturable').checked;
 		var dateCommandeDebut = document.getElementById('oma-dateCommandeDebut').value;
 		var dateCommandeFin = document.getElementById('oma-dateCommandeFin').value;
 		var dateExpeditionDebut = document.getElementById('oma-dateExpeditionDebut').value;
@@ -471,6 +473,7 @@ function oma_listerCommandes() {
 			if (oma_modeTraitement=="C") {
 
 				document.getElementById('oma-boxEtatLogistique').collapsed = (etatCommande!="T" && !(etatCommande=="C" && !oma_hidPretExpedier));
+				document.getElementById('oma-facturable').collapsed = etatCommande!="T";
 				document.getElementById('oma-etatAffaire').value = oma_defautEtatCommande;
 				document.getElementById('oma-bValiderCommande').disabled = true;
 
@@ -485,6 +488,7 @@ function oma_listerCommandes() {
 				oma_qListCC.setParam("Etat_Commande", etatCommande);
 				oma_qListCC.setParam("Etat_Logistique", etatLogistique);
 				oma_qListCC.setParam("Commande_Bloquee", commandeBloquee);
+				oma_qListCC.setParam("Facturable", facturable);
 				oma_qListCC.setParam("Date_Commande_Debut", dateCommandeDebut);
 				oma_qListCC.setParam("Date_Commande_Fin", dateCommandeFin);
 				oma_qListCC.setParam("Date_Expedition_Debut", dateExpeditionDebut);
@@ -563,6 +567,7 @@ function oma_listerCommandes() {
 				document.getElementById('oma-boxEtatLogistique').collapsed = true;
 				document.getElementById('oma-etatLogistique').value = oma_defautEtatLogistique;
 				document.getElementById('oma-bloque').selectedIndex = 0;
+				document.getElementById('oma-facturable').checked = false;
 				document.getElementById('oma-montantTTC').value = "";
 				document.getElementById('oma-etatPaiement').value = oma_defautEtatPaiement;
 				document.getElementById('oma-modeReglement').selectedIndex = 0;
@@ -905,6 +910,7 @@ function oma_pressOnEditionCsv() {
 		var etatCommande = document.getElementById('oma-etatCommande').value;
 		var etatLogistique = document.getElementById('oma-etatLogistique').value;
 		var commandeBloquee = document.getElementById('oma-bloque').value;
+		var facturable = document.getElementById('oma-facturable').checked;
 		var dateCommandeDebut = document.getElementById('oma-dateCommandeDebut').value;
 		var dateCommandeFin = document.getElementById('oma-dateCommandeFin').value;
 		var dateExpeditionDebut = document.getElementById('oma-dateExpeditionDebut').value;
@@ -946,6 +952,7 @@ function oma_pressOnEditionCsv() {
 				qEditionCsv.setParam("Etat_Commande", etatCommande);
 				qEditionCsv.setParam("Etat_Logistique", etatLogistique);
 				qEditionCsv.setParam("Commande_Bloquee", commandeBloquee);
+				qEditionCsv.setParam("Facturable", facturable);
 				qEditionCsv.setParam("Date_Commande_Debut", dateCommandeDebut);
 				qEditionCsv.setParam("Date_Commande_Fin", dateCommandeFin);
 				qEditionCsv.setParam("Date_Expedition_Debut", dateExpeditionDebut);
@@ -1026,6 +1033,7 @@ function oma_pressOnEditionCsvArticles() {
 		var etatCommande = document.getElementById('oma-etatCommande').value;
 		var etatLogistique = document.getElementById('oma-etatLogistique').value;
 		var commandeBloquee = document.getElementById('oma-bloque').value;
+		var facturable = document.getElementById('oma-facturable').checked;
 		var dateCommandeDebut = document.getElementById('oma-dateCommandeDebut').value;
 		var dateCommandeFin = document.getElementById('oma-dateCommandeFin').value;
 		var dateExpeditionDebut = document.getElementById('oma-dateExpeditionDebut').value;
@@ -1067,6 +1075,7 @@ function oma_pressOnEditionCsvArticles() {
 				qEditionCsv.setParam("Etat_Commande", etatCommande);
 				qEditionCsv.setParam("Etat_Logistique", etatLogistique);
 				qEditionCsv.setParam("Commande_Bloquee", commandeBloquee);
+				qEditionCsv.setParam("Facturable", facturable);
 				qEditionCsv.setParam("Date_Commande_Debut", dateCommandeDebut);
 				qEditionCsv.setParam("Date_Commande_Fin", dateCommandeFin);
 				qEditionCsv.setParam("Date_Expedition_Debut", dateExpeditionDebut);
@@ -1126,6 +1135,7 @@ function oma_pressOnEditionPdf() {
 		var etatCommande = document.getElementById('oma-etatCommande').value;
 		var etatLogistique = document.getElementById('oma-etatLogistique').value;
 		var commandeBloquee = document.getElementById('oma-bloque').value;
+		var facturable = document.getElementById('oma-facturable').checked;
 		var dateCommandeDebut = document.getElementById('oma-dateCommandeDebut').value;
 		var dateCommandeFin = document.getElementById('oma-dateCommandeFin').value;
 		var dateExpeditionDebut = document.getElementById('oma-dateExpeditionDebut').value;
@@ -1171,6 +1181,7 @@ function oma_pressOnEditionPdf() {
 			qEditionPdf.setParam("Etat_Commande", etatCommande);
 			qEditionPdf.setParam("Etat_Logistique", etatLogistique);
 			qEditionPdf.setParam("Commande_Bloquee", commandeBloquee);
+			qEditionPdf.setParam("Facturable", facturable);
 			qEditionPdf.setParam("Date_Commande_Debut", dateCommandeDebut);
 			qEditionPdf.setParam("Date_Commande_Fin", dateCommandeFin);
 			qEditionPdf.setParam("Date_Expedition_Debut", dateExpeditionDebut);
@@ -1296,6 +1307,10 @@ function oma_pressOnEtatCommande() {
 		document.getElementById("oma-miPartExpe").setAttribute("hidden", cloture);
 		document.getElementById("oma-miExpedie").setAttribute("hidden", cloture);
 
+		if (etatCommande!="T") {
+			document.getElementById('oma-facturable').checked = false;
+		}
+
 	} catch (e) {
 		recup_erreur(e);
 	}
