@@ -33,8 +33,17 @@ function omf_init() {
 
 		document.getElementById("omf-boxTotaux").collapsed = !gProfil.isShowTotauxDV();
 
+		if (gConfig.isGDVSituation()) {
+			document.getElementById('omf-typeDocFS').setAttribute("hidden", false);
+		}
+
 		omf_aModesReglements.initTree(omf_initModeReglement);
 
+		document.getElementById('omf-afColPourcentageFS').collapsed = true;
+		document.getElementById('omf-afColPourcentageFS').setAttribute('ignoreincolumnpicker', true);
+		document.getElementById('omf-afColQteCommande').collapsed = true;
+		document.getElementById('omf-afColQteCommande').setAttribute('ignoreincolumnpicker', true);
+
   } catch (e) {
   	recup_erreur(e);
   }
@@ -284,6 +293,7 @@ function omf_afterMajPagination() {
 
 function omf_selectOnListeFactures() {
 	try {
+
 		if (omf_aFactures.isSelected()) {
 			var documentId = omf_aFactures.getSelectedCellText('omf-colFactureId');
 			var typeDoc = omf_aFactures.getSelectedCellText('omf-colTypeDoc');
@@ -300,7 +310,16 @@ function omf_selectOnListeFactures() {
 
 			var editionTTC = (omf_aFactures.getSelectedCellText("omf-colEditionTTC")=="true");
 			document.getElementById('omf-afColMontant').setAttribute("label", editionTTC?"Montant TTC":"Montant HT");
+
+			var situation = (omf_aFactures.getSelectedCellText("omf-colSituation")=="true");
+			document.getElementById('omf-afColQteCommande').collapsed = !situation;
+			document.getElementById('omf-afColQteCommande').setAttribute('ignoreincolumnpicker', !situation);
+			document.getElementById('omf-afColPourcentageFS').collapsed = !situation;
+			document.getElementById('omf-afColPourcentageFS').setAttribute('ignoreincolumnpicker', !situation);
+			document.getElementById('omf-afColQuantite').collapsed = situation;
+			document.getElementById('omf-afColQuantite').setAttribute('ignoreincolumnpicker', situation);
 		}
+
 	} catch (e) {
 		recup_erreur(e);
 	}
