@@ -182,6 +182,28 @@ function oe_initModeReglement() {
 }
 
 
+function oe_nouveauReglement() {
+	try {
+
+		oe_currentEcheanceId = "";
+		document.getElementById('oe-dateReglement').value = "";
+		document.getElementById('oe-echeanceRemise').value = "";
+		oe_aBanquesClient.deleteTree();
+		oe_initBanqueClient();
+		oe_chargerClients("","");
+		oe_chargerModesReglements("");
+		oe_chargerBanques("");
+		document.getElementById('oe-numPiece').value = "";
+		document.getElementById('oe-tiersPayeur').value = "";
+		document.getElementById('oe-montant').value = "";
+		document.getElementById('oe-commentaires').value = "";
+
+	} catch (e) {
+    recup_erreur(e);
+  }
+}
+
+
 function oe_initListeHaut() {
 	try {
 
@@ -227,6 +249,7 @@ function oe_initListeHaut() {
 			document.getElementById('oe-bRegulariser').collapsed = (modeTraitement=="F" || gReadOnly);
 			document.getElementById('oe-bSolderEcheances').collapsed = (modeTraitement=="F" || gReadOnly);
 			document.getElementById('oe-grpReglements').collapsed = (modeTraitement=="F");
+			document.getElementById('oe-bModifierEcheances').collapsed = (modeTraitement=="F" || gReadOnly);
 
 			if (modeTraitement=="F") {
 				document.getElementById('oe-listePieces').disabled = true;
@@ -237,21 +260,12 @@ function oe_initListeHaut() {
 			else {
 				document.getElementById('oe-listeEcheances').disabled = true;
 				document.getElementById('oe-bRegulariser').disabled = true;
+				document.getElementById('oe-bModifierEcheances').disabled = true;
 				oe_aEcheances.deleteTree();
 				oe_aReglements.deleteTree();
 			}
 
-			oe_currentEcheanceId = "";
-			document.getElementById('oe-dateReglement').value = "";
-			document.getElementById('oe-echeanceRemise').value = "";
-			oe_aBanquesClient.deleteTree();
-			oe_chargerClients("","");
-			oe_chargerModesReglements("");
-			oe_chargerBanques("");
-			document.getElementById('oe-numPiece').value = "";
-			document.getElementById('oe-tiersPayeur').value = "";
-			document.getElementById('oe-montant').value = "";
-			document.getElementById('oe-commentaires').value = "";
+			oe_nouveauReglement();
 
 			if (modeTraitement=="F") {
 				oe_qListPC.setParam("Num_Client", numClient);
@@ -381,21 +395,11 @@ function oe_majPagination() {
 		else {
 			document.getElementById('oe-listeEcheances').disabled = true;
 			document.getElementById('oe-bRegulariser').disabled = true;
+			document.getElementById('oe-bModifierEcheances').disabled = true;
 			oe_aReglements.deleteTree();
 		}
 
-		oe_currentEcheanceId = "";
-		document.getElementById('oe-dateReglement').value = "";
-		document.getElementById('oe-echeanceRemise').value = "";
-		oe_aBanquesClient.deleteTree();
-		oe_initBanqueClient();
-		oe_chargerClients("","");
-		oe_chargerModesReglements("");
-		oe_chargerBanques("");
-		document.getElementById('oe-numPiece').value = "";
-		document.getElementById('oe-tiersPayeur').value = "";
-		document.getElementById('oe-montant').value = "";
-		document.getElementById('oe-commentaires').value = "";
+		oe_nouveauReglement();
 
 		if (modeTraitement=="F") {
 			oe_qListPC.setParam("Current_Page", oe_pageCourante);
@@ -540,7 +544,7 @@ function oe_manageDateArrete() {
 			document.getElementById('oe-dateArrete').collapsed = true;
 			document.getElementById('oe-dateArrete').value = "";
 		}
-	
+
 	} catch (e) {
 		recup_erreur(e);
 	}
@@ -708,8 +712,10 @@ function oe_pressOnListeEcheancesFact() {
 	try {
 
 		if (!gReadOnly && !isEmpty(oe_currentEcheanceId)) {
+			var listEcheanceId = new Array();
+			listEcheanceId.push(oe_currentEcheanceId);
 			var url = "chrome://opensi/content/facturation/user/suivi_reglements_clients/popup-modifierEcheance.xul";
-			window.openDialog(url,'','chrome,modal,centerscreen', oe_currentEcheanceId, oe_selectOnListePieces);
+			window.openDialog(url,'','chrome,modal,centerscreen', listEcheanceId, oe_selectOnListePieces);
 		}
 
 	} catch (e) {
@@ -720,29 +726,40 @@ function oe_pressOnListeEcheancesFact() {
 
 function oe_selectOnListeEcheances() {
 	try {
+
 		if (oe_aEcheances.isSelected()) {
-			var i = oe_aEcheances.getCurrentIndex();
-			oe_currentEcheanceId = oe_aEcheances.getCellText(i, 'oe-colEcheanceId');
 
-			var clientId = oe_aEcheances.getCellText(i, 'oe-colClientId');
-			var denomination = "";
-			if (clientId=="") { denomination = oe_aEcheances.getCellText(i, 'oe-colDenomination'); }
+			if (oe_aEcheances.nbSelection()==1) {
+				var i = oe_aEcheances.getCurrentIndex();
+				oe_currentEcheanceId = oe_aEcheances.getCellText(i, 'oe-colEcheanceId');
 
-			oe_chargerClients(clientId, denomination);
-			oe_chargerModesReglements(oe_aEcheances.getCellText(i, 'oe-colModeRegId'));
-			oe_chargerBanques(oe_aEcheances.getCellText(i, 'oe-colBanqueRemise'));
+				var clientId = oe_aEcheances.getCellText(i, 'oe-colClientId');
+				var denomination = "";
+				if (clientId=="") { denomination = oe_aEcheances.getCellText(i, 'oe-colDenomination'); }
 
-			document.getElementById('oe-dateReglement').value = getDateCourante();
-			document.getElementById('oe-echeanceRemise').value = "";
-			document.getElementById('oe-numPiece').value = "";
-			document.getElementById('oe-tiersPayeur').value = "";
-			document.getElementById('oe-montant').value = oe_aEcheances.getCellText(i, 'oe-colMontant');
-			document.getElementById('oe-commentaires').value = oe_aEcheances.getCellText(i, 'oe-colCommentaires');
-			document.getElementById('oe-bRegulariser').disabled = (oe_aEcheances.getCellText(i, 'oe-colEtat')=="T");
+				oe_chargerClients(clientId, denomination);
+				oe_chargerModesReglements(oe_aEcheances.getCellText(i, 'oe-colModeRegId'));
+				oe_chargerBanques(oe_aEcheances.getCellText(i, 'oe-colBanqueRemise'));
 
-			oe_aReglements.setParam("Echeance_Id", oe_currentEcheanceId);
-			oe_aReglements.initTree();
+				document.getElementById('oe-dateReglement').value = getDateCourante();
+				document.getElementById('oe-echeanceRemise').value = "";
+				document.getElementById('oe-numPiece').value = "";
+				document.getElementById('oe-tiersPayeur').value = "";
+				document.getElementById('oe-montant').value = oe_aEcheances.getCellText(i, 'oe-colMontant');
+				document.getElementById('oe-commentaires').value = oe_aEcheances.getCellText(i, 'oe-colCommentaires');
+				document.getElementById('oe-bRegulariser').disabled = (oe_aEcheances.getCellText(i, 'oe-colEtat')=="T");
+				document.getElementById('oe-bModifierEcheances').disabled = true;
+
+				oe_aReglements.setParam("Echeance_Id", oe_currentEcheanceId);
+				oe_aReglements.initTree();
+			}
+			else {
+				document.getElementById('oe-bRegulariser').disabled = true;
+				oe_nouveauReglement();
+				document.getElementById('oe-bModifierEcheances').disabled = false;
+			}
 		}
+
 	} catch (e) {
 		recup_erreur(e);
 	}
@@ -752,9 +769,43 @@ function oe_selectOnListeEcheances() {
 function oe_pressOnListeEcheances() {
 	try {
 
-		if (!gReadOnly && !isEmpty(oe_currentEcheanceId)) {
-			var url = "chrome://opensi/content/facturation/user/suivi_reglements_clients/popup-modifierEcheance.xul";
-			window.openDialog(url,'','chrome,modal,centerscreen', oe_currentEcheanceId, oe_initListeHaut);
+		if (!gReadOnly) {
+			oe_modifierEcheance();
+		}
+
+	} catch (e) {
+		recup_erreur(e);
+	}
+}
+
+
+function oe_modifierEcheance() {
+	try {
+
+		if (oe_aEcheances.isSelected()) {
+
+			var listEcheanceId = new Array();
+
+			if (!isEmpty(oe_currentEcheanceId)) {
+				listEcheanceId.push(oe_currentEcheanceId);
+			}
+			else {
+				var start = new Object();
+				var end = new Object();
+				var numRanges = oe_aEcheances.getRangeCount();
+
+				for (var t=0; t<numRanges; t++){
+					oe_aEcheances.getRangeAt(t,start,end);
+			  	for (var v=start.value; v<=end.value; v++){
+		  			listEcheanceId.push(oe_aEcheances.getCellText(v,'oe-colEcheanceId'));
+			  	}
+				}
+			}
+
+			if (listEcheanceId.length>0) {
+				var url = "chrome://opensi/content/facturation/user/suivi_reglements_clients/popup-modifierEcheance.xul";
+				window.openDialog(url,'','chrome,modal,centerscreen', listEcheanceId, oe_initListeHaut);
+			}
 		}
 
 	} catch (e) {
