@@ -32,6 +32,7 @@ var oe_typeEdition = "E"; // E = chancier normal; P = chancier prvisionnel
 
 function oe_init() {
   try {
+
     oe_initListeHaut();
   	document.getElementById('oe-etat').value = "N";
   	document.getElementById('oe-rechDenomination').value = "";
@@ -153,7 +154,27 @@ function oe_chargerModesReglements(selection) {
 function oe_initModeReglement() {
 	try {
 
-    document.getElementById('oe-modeReglement').value=oe_chargerModeReg;
+		document.getElementById('oe-modeReglement').value = oe_chargerModeReg;
+
+	} catch (e) {
+    recup_erreur(e);
+  }
+}
+
+
+function oe_nouveauReglement() {
+	try {
+
+		oe_currentEcheanceId = "";
+		document.getElementById('oe-dateReglement').value = "";
+		oe_aBanquesFournisseur.deleteTree();
+		oe_initBanqueFournisseur();
+		oe_chargerFournisseurs("","");
+		oe_chargerModesReglements("");
+		oe_chargerBanques("");
+		document.getElementById('oe-numPiece').value = "";
+		document.getElementById('oe-montant').value = "";
+		document.getElementById('oe-commentaires').value = "";
 
 	} catch (e) {
     recup_erreur(e);
@@ -203,6 +224,7 @@ function oe_initListeHaut() {
 			document.getElementById('oe-listeEcheances').collapsed = (modeTraitement=="F");
 			document.getElementById('oe-bRegulariser').collapsed = (modeTraitement=="F");
 			document.getElementById('oe-grpReglements').collapsed = (modeTraitement=="F");
+			document.getElementById('oe-bModifierEcheances').collapsed = (modeTraitement=="F");
 
 			if (modeTraitement=="F") {
 				document.getElementById('oe-listePieces').disabled = true;
@@ -213,19 +235,12 @@ function oe_initListeHaut() {
 			else {
 				document.getElementById('oe-listeEcheances').disabled = true;
 				document.getElementById('oe-bRegulariser').disabled = true;
+				document.getElementById('oe-bModifierEcheances').disabled = true;
 				oe_aEcheances.deleteTree();
 				oe_aReglements.deleteTree();
 			}
 
-			oe_currentEcheanceId = "";
-			document.getElementById('oe-dateReglement').value = "";
-			oe_aBanquesFournisseur.deleteTree();
-			oe_chargerFournisseurs("","");
-			oe_chargerModesReglements("");
-			oe_chargerBanques("");
-			document.getElementById('oe-numPiece').value = "";
-			document.getElementById('oe-montant').value = "";
-			document.getElementById('oe-commentaires').value = "";
+			oe_nouveauReglement();
 
 			if (modeTraitement=="F") {
 				oe_qListPF.setParam("Num_Fournisseur", numFournisseur);
@@ -346,19 +361,11 @@ function oe_majPagination() {
 		} else {
 			document.getElementById('oe-listeEcheances').disabled = true;
 			document.getElementById('oe-bRegulariser').disabled = true;
+			document.getElementById('oe-bModifierEcheances').disabled = true;
 			oe_aReglements.deleteTree();
 		}
 
-		oe_currentEcheanceId = "";
-		document.getElementById('oe-dateReglement').value = "";
-		oe_aBanquesFournisseur.deleteTree();
-		oe_initBanqueFournisseur();
-		oe_chargerFournisseurs("","");
-		oe_chargerModesReglements("");
-		oe_chargerBanques("");
-		document.getElementById('oe-numPiece').value = "";
-		document.getElementById('oe-montant').value = "";
-		document.getElementById('oe-commentaires').value = "";
+		oe_nouveauReglement();
 
 		if (modeTraitement=="F") {
 			oe_qListPF.setParam("Current_Page", oe_pageCourante);
@@ -646,32 +653,44 @@ function oe_selectFournisseur() {
 
 function oe_selectOnListeEcheances() {
 	try {
+
 		if (oe_aEcheances.isSelected()) {
-			var i = oe_aEcheances.getCurrentIndex();
-			oe_currentEcheanceId = oe_aEcheances.getCellText(i, 'oe-colEcheanceId');
 
-			var fournisseurId = oe_aEcheances.getCellText(i, 'oe-colFournisseurId');
-			var denomination = "";
-			if (fournisseurId=="") { denomination = oe_aEcheances.getCellText(i, 'oe-colDenomination'); }
+			if (oe_aEcheances.nbSelection()==1) {
+				var i = oe_aEcheances.getCurrentIndex();
+				oe_currentEcheanceId = oe_aEcheances.getCellText(i, 'oe-colEcheanceId');
 
-			oe_chargerFournisseurs(fournisseurId, denomination);
-			oe_chargerModesReglements(oe_aEcheances.getCellText(i, 'oe-colModeRegId'));
-			oe_chargerBanques(oe_aEcheances.getCellText(i, 'oe-colBanqueRetrait'));
+				var fournisseurId = oe_aEcheances.getCellText(i, 'oe-colFournisseurId');
+				var denomination = "";
+				if (fournisseurId=="") { denomination = oe_aEcheances.getCellText(i, 'oe-colDenomination'); }
 
-			document.getElementById('oe-dateReglement').value = oe_aEcheances.getCellText(i, 'oe-colDateEcheance');
-			document.getElementById('oe-numPiece').value = "";
-			document.getElementById('oe-montant').value = oe_aEcheances.getCellText(i, 'oe-colMontant');
-			document.getElementById('oe-commentaires').value = oe_aEcheances.getCellText(i, 'oe-colCommentaires');
-			document.getElementById('oe-bRegulariser').disabled = (oe_aEcheances.getCellText(i, 'oe-colEtat')=="T");
+				oe_chargerFournisseurs(fournisseurId, denomination);
+				oe_chargerModesReglements(oe_aEcheances.getCellText(i, 'oe-colModeRegId'));
+				oe_chargerBanques(oe_aEcheances.getCellText(i, 'oe-colBanqueRetrait'));
 
-			oe_aReglements.setParam("Echeance_Id", oe_currentEcheanceId);
-			oe_aReglements.initTree();
+				document.getElementById('oe-dateReglement').value = oe_aEcheances.getCellText(i, 'oe-colDateEcheance');
+				document.getElementById('oe-numPiece').value = "";
+				document.getElementById('oe-montant').value = oe_aEcheances.getCellText(i, 'oe-colMontant');
+				document.getElementById('oe-commentaires').value = oe_aEcheances.getCellText(i, 'oe-colCommentaires');
+				document.getElementById('oe-bRegulariser').disabled = (oe_aEcheances.getCellText(i, 'oe-colEtat')=="T");
+				document.getElementById('oe-bModifierEcheances').disabled = true;
+
+				oe_aReglements.setParam("Echeance_Id", oe_currentEcheanceId);
+				oe_aReglements.initTree();
+			}
+			else {
+				document.getElementById('oe-bRegulariser').disabled = true;
+				oe_nouveauReglement();
+				document.getElementById('oe-bModifierEcheances').disabled = false;
+			}
 		}
+
 	} catch (e) {
 		recup_erreur(e);
 	}
 }
 
+
 function oe_selectOnListeReglements() {
 	try {
 		document.getElementById('oe-bDesaffecter').disabled = !oe_aReglements.isSelected();
@@ -875,10 +894,7 @@ function oe_pressOnDateDebEcheance(event) {
 function oe_pressOnListeEcheances() {
 	try {
 
-		if (oe_currentEcheanceId != "") {
-			var url="chrome://opensi/content/facturation/user/suivi_reglements_fournisseurs/popup-modifierEcheance.xul?"+ cookie();
-			window.openDialog(url,'','chrome,modal,centerscreen', oe_currentEcheanceId, oe_initListeHaut);
-		}
+		oe_modifierEcheance();
 
 	} catch (e) {
 		recup_erreur(e);
@@ -889,9 +905,46 @@ function oe_pressOnListeEcheances() {
 function oe_pressOnListeEcheancesFact() {
 	try {
 
-		if (oe_currentEcheanceId != "") {
-			var url="chrome://opensi/content/facturation/user/suivi_reglements_fournisseurs/popup-modifierEcheance.xul?"+ cookie();
-			window.openDialog(url,'','chrome,modal,centerscreen', oe_currentEcheanceId, oe_selectOnListePieces);
+		if (!isEmpty(oe_currentEcheanceId)) {
+			var listEcheanceId = new Array();
+			listEcheanceId.push(oe_currentEcheanceId);
+			var url = "chrome://opensi/content/facturation/user/suivi_reglements_fournisseurs/popup-modifierEcheance.xul";
+			window.openDialog(url,'','chrome,modal,centerscreen', listEcheanceId, oe_selectOnListePieces);
+		}
+
+	} catch (e) {
+		recup_erreur(e);
+	}
+}
+
+
+function oe_modifierEcheance() {
+	try {
+
+		if (oe_aEcheances.isSelected()) {
+
+			var listEcheanceId = new Array();
+
+			if (!isEmpty(oe_currentEcheanceId)) {
+				listEcheanceId.push(oe_currentEcheanceId);
+			}
+			else {
+				var start = new Object();
+				var end = new Object();
+				var numRanges = oe_aEcheances.getRangeCount();
+
+				for (var t=0; t<numRanges; t++){
+					oe_aEcheances.getRangeAt(t,start,end);
+			  	for (var v=start.value; v<=end.value; v++){
+		  			listEcheanceId.push(oe_aEcheances.getCellText(v,'oe-colEcheanceId'));
+			  	}
+				}
+			}
+
+			if (listEcheanceId.length>0) {
+				var url = "chrome://opensi/content/facturation/user/suivi_reglements_fournisseurs/popup-modifierEcheance.xul";
+				window.openDialog(url,'','chrome,modal,centerscreen', listEcheanceId, oe_initListeHaut);
+			}
 		}
 
 	} catch (e) {
