@@ -19,7 +19,7 @@ function init() {
   	document.getElementById("contenu").setAttribute("src", page);
 
 		if (ParamValeur("VTest")=="true") {
-			document.getElementById("imgLogo").setAttribute("src", "chrome://opensi/content/design/logo-test-conf.jpg");
+			document.getElementById("imgLogo").setAttribute("src", "chrome://opensi/content/design/logo-test-conf.svg");
 		}
 
 		document.getElementById("date_courante").value = getDateCourante();
