@@ -20,7 +20,7 @@ function init() {
     document.getElementById("login").value = ParamValeur("Utilisateur");
 
 		if (ParamValeur("VTest")=="true") {
-			document.getElementById("imgLogo").setAttribute("src", "chrome://opensi/content/design/logo-test-conf.jpg");
+			document.getElementById("imgLogo").setAttribute("src", "chrome://opensi/content/design/logo-test-conf.svg");
 		}
 
 		document.getElementById("date_courante").value = getDateCourante();
